@@ -14,6 +14,8 @@
 
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ungettext_lazy
+
 from horizon import tables
 
 from cloudkittydashboard.api import cloudkitty as api
@@ -22,14 +24,55 @@ ENABLE = 0
 DISABLE = 1
 
 
+class EditModulePriority(tables.LinkAction):
+    name = "editmodulepriority"
+    verbose_name = _("Edit module priority")
+    icon = "edit"
+    ajax = True
+    classes = ("ajax-modal",)
+
+    def get_link_url(self, datum):
+        if datum.module_id:
+            url = "horizon:admin:rating_modules:edit_priority"
+            return reverse(url, kwargs={'module_id': datum.module_id})
+
+
 class ToggleEnabledModule(tables.BatchAction):
     name = "toggle_module"
-    action_present = (_("Enable"), _("Disable"))
-    action_past = (_("Enabled"), _("Disabled"))
     data_type_singular = _("Module")
     data_type_plural = _("Modules")
     classes = ("btn-toggle",)
 
+    @staticmethod
+    def action_present(count):
+        return (
+            ungettext_lazy(
+                u"Enable Module",
+                u"Enable Modules",
+                count
+            ),
+            ungettext_lazy(
+                u"Disable Module",
+                u"Disable Modules",
+                count
+            ),
+        )
+
+    @staticmethod
+    def action_past(count):
+        return (
+            ungettext_lazy(
+                u"Enabled Module",
+                u"Enabled Modules",
+                count
+            ),
+            ungettext_lazy(
+                u"Disabled Module",
+                u"Disabled Modules",
+                count
+            ),
+        )
+
     def allowed(self, request, module=None):
         self.enabled = module.enabled
         if self.enabled:
@@ -59,9 +102,10 @@ class ModulesTable(tables.DataTable):
     name = tables.Column('name', verbose_name=_("Name"), link=get_details_link)
     description = tables.Column('description', verbose_name=_("Description"))
     hot_config = tables.Column('hot-config', verbose_name=_("Configurable"))
+    priority = tables.Column('priority', verbose_name=_("Priority"))
     enabled = tables.Column('enabled', verbose_name=_("Enabled"))
 
     class Meta(object):
         name = "modules"
         verbose_name = _("Modules")
-        row_actions = (ToggleEnabledModule,)
+        row_actions = (ToggleEnabledModule, EditModulePriority)
